﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;
using Pokkt;

public class VideoOperations : MonoBehaviour
{
	// exposed properties
	public GameObject ScreenManagerGO;
	public Button StartCacheButton;
	public Button PlayVideoIncentButton;
	public Button PlayVideoNonIncentButton;
	public Text PointsEarned;
	public Text StatusMessage;

	// internal states
	private int _totalPointsEarned = 0;

	void Awake()
	{
		// this will be a unique id per user from developer side
		// developer is free to choose any String data point.
		PokktManager.GetInstance().SetThirdPartyUserId("123456");

		// enable 'Start Caching' button in case of manual caching
		StartCacheButton.gameObject.SetActive(!PokktManager.GetInstance().AutoCaching);

		// set default skip time
		PokktManager.GetInstance().SetDefaultSkipTime("10");

		// handle pokkt video ad events
		PokktManager.GetInstance().Dispathcer.VideoClosedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		PokktManager.GetInstance().Dispathcer.VideoSkippedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		PokktManager.GetInstance().Dispathcer.VideoCompletedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};
		
		PokktManager.GetInstance().Dispathcer.VideoGratifiedEvent += (string message) =>
		{
			_totalPointsEarned += int.Parse(message);
			
			PointsEarned.text = "Points Earned: " + _totalPointsEarned.ToString();
			StatusMessage.text = "Points earned from last video: " + message;
		};
		
		PokktManager.GetInstance().Dispathcer.VideoDisplayedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		PokktManager.GetInstance().Dispathcer.ShowIntentEvent += (string message) =>
		{
			ShowIntent();
		};
		
		PokktManager.GetInstance().Dispathcer.DownloadCompletedEvent += (string message) =>
		{
			StatusMessage.text = "Download Completed! VC is: " + message;

			// enable playback buttons
			PlayVideoIncentButton.gameObject.SetActive(true);
			PlayVideoNonIncentButton.gameObject.SetActive(true);

			// get the video vc
			int vc = PokktManager.GetInstance().GetVideoVc();
			PlayVideoIncentButton.GetComponentInChildren<Text>().text = "Play Video To Earn: " + vc.ToString();
		};
		
		PokktManager.GetInstance().Dispathcer.DownloadFailedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};
	}

	void Start()
	{
	}
	
	void Update()
	{
		if (Input.GetKeyDown(KeyCode.Escape))
		{
			ScreenManagerGO.GetComponent<ScreenManager>().OpenScreen("CampaignSelectorScreen");

			// disable buttons
			StartCacheButton.gameObject.SetActive(!PokktManager.GetInstance().AutoCaching);
			PlayVideoIncentButton.gameObject.SetActive(false);
			PlayVideoNonIncentButton.gameObject.SetActive(false);
			
		}
	}

	public void StartCaching()
	{
		PokktManager.GetInstance().StartVideoCaching();
	}

	public void PlayVideo(bool incent)
	{
		if (incent)
			PokktManager.GetInstance().GetVideo();
		else
			PokktManager.GetInstance().GetVideoNonIncent();
	}

	public void PlayVideoWithIntent()
	{
		if (PokktManager.GetInstance().IsVideoAvailable())
			PokktManager.GetInstance().GetVideoWithIntent();
		else
			ShowIntent();
	}

	public void ShowIntent()
	{
		ScreenManagerGO.GetComponent<ScreenManager>().OpenScreen("IntentDemoScreen");
	}
}
